==> xcsoar-6.8.13.tar.xz: xcsoar-6.8.13/src/Renderer/WaveRenderer.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2015 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_WAVE_RENDERER_HPP
#define XCSOAR_WAVE_RENDERER_HPP

struct WaveInfo;
struct WaveResult;
struct WaveLook;
class Canvas;
class WindowProjection;
class GeoClip;

class WaveRenderer {
  const WaveLook &look;

public:
  WaveRenderer(const WaveLook &_look):look(_look) {}

  void Draw(Canvas &canvas, const WindowProjection &projection,
            const GeoClip &clip,
            const WaveInfo &wave) const;

  void Draw(Canvas &canvas, const WindowProjection &projection,
            const WaveInfo &wave) const;

  void Draw(Canvas &canvas, const WindowProjection &projection,
            const WaveResult &result) const;
};

#endif

==> xcsoar-7.15.tar.xz: xcsoar-7.15/src/Renderer/WaveRenderer.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_WAVE_RENDERER_HPP
#define XCSOAR_WAVE_RENDERER_HPP

struct GeoPoint;
struct WaveInfo;
struct WaveResult;
struct WaveLook;
class Canvas;
class WindowProjection;
class GeoClip;

namespace SkyLinesTracking {
  struct Data;
}

class WaveRenderer {
  const WaveLook &look;

public:
  WaveRenderer(const WaveLook &_look):look(_look) {}

  void Draw(Canvas &canvas, const WindowProjection &projection,
            const GeoClip &clip, GeoPoint a, GeoPoint b) const;

  void Draw(Canvas &canvas, const WindowProjection &projection,
            const GeoClip &clip,
            const WaveInfo &wave) const;

  void Draw(Canvas &canvas, const WindowProjection &projection,
            const WaveInfo &wave) const;

  void Draw(Canvas &canvas, const WindowProjection &projection,
            const WaveResult &result) const;

  void Draw(Canvas &canvas, const WindowProjection &projection,
            const SkyLinesTracking::Data &data) const;
};

#endif
